#' LMS Parameters for the Centers for Disease Control and Prevention
#' 2000 Growth Charts, contains bmi, height, head cirumference, weight,
#' weight for length, 
#' @name cdc.ref
#' @docType data
#' @usage cdc.ref
#' @source National health statitics reports 63.
NULL

#' LMS Parameters for German reference data (KiGGS, 2003-2006)
#' for height, weight, bmi, hip, whr, whtr, bodyfat, skinfold sum, triceps
#' skinfold, subscapular skinfold, and waist circumference
#' @name kiggs.ref 
#' @docType data
#' @usage kiggs.ref
#' @source Referenzperzentile fuer anthropometrische Masszahlen und Blutdruck aus KiGGS 2003-2006, Robert Koch Institut, Germany
NULL


#' LMS Parameters for German reference data (Kromeyer Hauschild, 2001)
#' for height, weight, bmi, and waist circumference, including preterm
#' correction (Voigt)
#' @name kro.ref
#' @docType data
#' @usage kro.ref
#' @source Perzentile fuer den Body-mass-Index fuer das Kindes- und Jugendalter unter Heranziehung verschiedener deutscher Stichproben, Monatsschrift Kinderheilkunde August 2001, Volume 149, Issue 8, pp 807-818; Fruehgeborenenkorrektur nach Voigt
NULL

#' LMS Parameters for UK-WHO growth charts for height,
#' weight, bmi, head circumference
#' @name ukwho.ref
#' @docType data
#' @usage ukwho.ref
#' @source Wright, Charlotte M., et a,Practice pointer: Using the new UK-WHO growth charts. British Medical Journal 340.c1140 (2010): 647-650.Preterm British 1990, 0-4 WHO2006, 4-18 British1990
NULL


#' LMS Parameters for UK-WHO growth charts for height, weight, bmi,
#' head circumference,arm mid upper arm circumference, subscapular
#' and triceps skinfold, weight for height
#' @name who.ref
#' @docType data
#' @usage who.ref
#' @source de Onis, M., Onyango, A., Borghi, E., Siyam, A., Blossner, M., & Lutter, C. (2012). Worldwide implementation of the WHO child growth standards. Public Health Nutr, 12, 1-8.
NULL


#' Parameters for iron-related blood parameters in children
#' @name iron.ref
#' @docType data
#' @usage iron.ref
#' @source Rieger, K. et al. Reference intervals for iron-related blood parameters: results from a population-based cohort study (LIFE Child). LaboratoriumsMedizin 40, (2016).
NULL


#' Parameters for serum lipids in children
#' @name lipids.ref
#' @docType data
#' @usage lipids.ref
#' @source Dathan-Stumpf, A. et al. Pediatric reference data of serum lipids and prevalence of dyslipidemia: Results from a population-based cohort in Germany. Clinical Biochemistry 49, 740--749 (2016).
NULL

#' Parameters derived from Turkish children
#' @name turkish.ref
#' @docType data
#' @usage turkish.ref
#' @source Hatipoglu, N. et al. Waist circumference percentiles for 7- to 17-year-old Turkish children and adolescents. Eur J Pediatr 167, 383--389 (2008);Bundak, R. et al. Body mass index references for Turkish children. Acta Pædiatrica 95, 194--198 (2006).
NULL


#' Parameters derived from Japanese children
#' @name japanese.ref
#' @docType data
#' @usage japanese.ref
#' @source Inokuchi, M., Matsuo, N., Anzo, M., Takayama, J. I. & Hasegawa, T. Age-dependent percentile for waist circumference for Japanese children based on the 1992--1994 cross-sectional national survey data. Eur J Pediatr 166, 655--661 (2007)
NULL


#' Parameters derived from US children (additional to the cdc.ref)
#' @name us.ref
#' @docType data
#' @usage us.ref
#' @source Sharma, A. K., Metzger, D. L., Daymont, C., Hadjiyannakis, S. & Rodd, C. J. LMS tables for waist-circumference and waist-height ratio Z-scores in children aged 5-19 y in NHANES III: association with cardio-metabolic risks. Pediatric research (2015)
NULL


#' Parameters derived from Saudi children
#' @name saudi.ref
#' @docType data
#' @usage saudi.ref
#' @source
#' Mouzan, M. I. E., Salloum, A. A. A., Alqurashi, M. M., Herbish, A. S. A. & Omar, A. A. The LMS and Z scale growth reference for Saudi school-age children and adolescents. Saudi Journal of Gastroenterology 22, 331 (2016)
NULL


#' Parameters derived Ethiopian children
#' @name ethiop.ref
#' @docType data
#' @usage ehtiop.ref
#' @source Amare, E. B. et al. Reference Ranges for Head Circumference in Ethiopian Children 0--2 Years of Age. World Neurosurgery 84, 1566--1571.e2 (2015).
NULL


#' Parameters derived from Portuguese children
#' @name portug.ref
#' @docType data
#' @usage portug.ref
#' @source Chaves, R., Baxter-Jones, A., Souza, M., Santos, D. & Maia, J. Height, weight, body composition, and waist circumference references for 7-to 17-year-old children from rural Portugal. HOMO-Journal of Comparative Human Biology 66, 264--277 (2015).
NULL


#' Parameters derived from Italian children
#' @name italian.ref
#' @docType data
#' @usage italian.ref
#' @source Cacciari E, Milani S, Balsamo A, Spada E, Bona G, Cavallo L, et al. Italian cross-sectional growth charts for height, weight and BMI (2 to 20 yr). J Endocrinol Invest. 2006 Jul 1;29(7):581--93.
NULL

#' Parameters derived from the 4th Dutch growth study
#' @name nl4.ref
#' @docType data
#' @usage nl4.ref
#' @source Fredriks, A. M. et al. Nationwide age references for sitting height, leg length, and sitting height/height ratio, and their diagnostic value for disproportionate growth disorders. Archives of Disease in Childhood 90, 807--812 (2005);
#' Fredriks, A. M. et al. Height, weight, body mass index and pubertal development references for children of Moroccan origin in The Netherlands. Acta Paediatr. 93, 817--824 (2004);
#' Fredriks, A. M. et al. Continuing positive secular growth change in The Netherlands 1955--1997. Pediatric research 47, 316--323 (2000);
#' Fredriks, A. M. et al. Height, weight, body mass index and pubertal development reference values for children of Turkish origin in the Netherlands. Eur. J. Pediatr. 162, 788--793 (2003); Fredriks, A. M., van Buuren, S., Wit, J. M. & Verloove-Vanhorick, S. P. Body index measurements in 1996--7 compared with 1980. Archives of disease in childhood 82, 107--112 (2000);
#' R package: AGD, Stef van Buuren, http://www.stefvanbuuren.nl/
NULL

#' Parameters derived from Dutch children (additional to nl4.ref)
#' @name fredriks05.ref
#' @docType data
#' @usage fredriks05.ref
#' @source Fredriks, A. M. et al. Nationwide age references for sitting height, leg length, and sitting height/height ratio, and their diagnostic value for disproportionate growth disorders. Archives of Disease in Childhood 90, 807--812 (2005)
NULL

#' Parameters derived from Chinese children (additional to nl4.ref)
#' @name zong13.ref
#' @docType data
#' @usage zong13.ref
#' @source Zong, X.-N., Li, H. Construction of a New Growth References for China Based on Urban Chinese Children: Comparison with the WHO Growth Standards. PLOS ONE 8, e59569 (2013).
NULL


#' Parameters derived from the German KiGGS cohort
#' @name kiggs_bp.ref
#' @docType data
#' @usage kiggs_bp.ref
#' @details contains 2-dimensional reference grid. Do not use with \code{\link{sds}} but \code{\link{sds_2d}}
#' @source Neuhauser, H. K., Thamm, M., Ellert, U., Hense, H. W. & Rosario, A. S. Blood Pressure Percentiles by Age and Height from Nonoverweight Children and Adolescents in Germany. Pediatrics peds.2010-1290 (2011). doi:10.1542/peds.2010-1290.
NULL

#' Parameters derived from Flandern population
#' @name belgium.ref
#' @docType data
#' @usage belgium.ref
#' @source Roelants M, Hauspie R, Hoppenbrouwers K. References for growth and pubertal development from birth to 21 years in Flanders, Belgium. Annals of Human Biology. 2009 Dezember;36(6):680–94.
NULL


#' Parameters of skinfold measures derived from Colombian population 
#' @name colombia_sf.ref
#' @docType data
#' @usage colombia_sf.ref
#' @source Ramírez-Vélez, R. et al. Triceps and Subscapular Skinfold Thickness Percentiles and Cut-Offs for Overweight and Obesity in a Population-Based Sample of Schoolchildren and Adolescents in Bogota, Colombia. Nutrients 8, (2016).
NULL


